/****************************************************************************
** Meta object code from reading C++ file 'qquick3dprincipledmaterial_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3dprincipledmaterial_p.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dprincipledmaterial_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN26QQuick3DPrincipledMaterialE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DPrincipledMaterial::qt_create_metaobjectdata<qt_meta_tag_ZN26QQuick3DPrincipledMaterialE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DPrincipledMaterial",
        "QML.Element",
        "PrincipledMaterial",
        "lightingChanged",
        "",
        "QQuick3DPrincipledMaterial::Lighting",
        "lighting",
        "blendModeChanged",
        "QQuick3DPrincipledMaterial::BlendMode",
        "blendMode",
        "baseColorChanged",
        "QColor",
        "baseColor",
        "baseColorMapChanged",
        "QQuick3DTexture*",
        "baseColorMap",
        "baseColorSingleChannelEnabledChanged",
        "baseColorSingleChannelEnabled",
        "baseColorChannelChanged",
        "QQuick3DMaterial::TextureChannelMapping",
        "channel",
        "specularSingleChannelEnabledChanged",
        "specularColorSingleChannelEnabled",
        "specularChannelChanged",
        "emissiveSingleChannelEnabledChanged",
        "emissiveColorSingleChannelEnabled",
        "emissiveChannelChanged",
        "emissiveMapChanged",
        "emissiveMap",
        "emissiveFactorChanged",
        "QVector3D",
        "emissiveFactor",
        "specularReflectionMapChanged",
        "specularReflectionMap",
        "specularMapChanged",
        "specularMap",
        "specularTintChanged",
        "specularTint",
        "specularAmountChanged",
        "specularAmount",
        "roughnessChanged",
        "roughness",
        "roughnessMapChanged",
        "roughnessMap",
        "invertOpacityMapValueChanged",
        "invertOpacityMapValue",
        "opacityChanged",
        "opacity",
        "opacityMapChanged",
        "opacityMap",
        "normalMapChanged",
        "normalMap",
        "metalnessChanged",
        "metalness",
        "metalnessMapChanged",
        "metalnessMap",
        "normalStrengthChanged",
        "normalStrength",
        "occlusionMapChanged",
        "occlusionMap",
        "occlusionAmountChanged",
        "occlusionAmount",
        "alphaModeChanged",
        "QQuick3DPrincipledMaterial::AlphaMode",
        "alphaMode",
        "alphaCutoffChanged",
        "alphaCutoff",
        "metalnessChannelChanged",
        "roughnessChannelChanged",
        "opacityChannelChanged",
        "occlusionChannelChanged",
        "pointSizeChanged",
        "lineWidthChanged",
        "heightMapChanged",
        "heightMap",
        "heightChannelChanged",
        "heightAmountChanged",
        "heightAmount",
        "minHeightMapSamplesChanged",
        "samples",
        "maxHeightMapSamplesChanged",
        "clearcoatAmountChanged",
        "amount",
        "clearcoatMapChanged",
        "texture",
        "clearcoatChannelChanged",
        "clearcoatRoughnessAmountChanged",
        "clearcoatRoughnessChannelChanged",
        "clearcoatRoughnessMapChanged",
        "clearcoatNormalMapChanged",
        "clearcoatNormalStrengthChanged",
        "clearcoatNormalStrength",
        "transmissionFactorChanged",
        "transmissionMapChanged",
        "transmissionChannelChanged",
        "thicknessFactorChanged",
        "thicknessMapChanged",
        "thicknessChannelChanged",
        "attenuationDistanceChanged",
        "distance",
        "attenuationColorChanged",
        "color",
        "indexOfRefractionChanged",
        "indexOfRefraction",
        "fresnelScaleBiasEnabledChanged",
        "fresnelScaleBiasEnabled",
        "fresnelScaleChanged",
        "fresnelScale",
        "fresnelBiasChanged",
        "fresnelBias",
        "fresnelPowerChanged",
        "fresnelPower",
        "clearcoatFresnelScaleBiasEnabledChanged",
        "clearcoatFresnelScaleBiasEnabled",
        "clearcoatFresnelScaleChanged",
        "clearcoatFresnelScale",
        "clearcoatFresnelBiasChanged",
        "clearcoatFresnelBias",
        "clearcoatFresnelPowerChanged",
        "clearcoatFresnelPower",
        "vertexColorsEnabledChanged",
        "vertexColorsEnabled",
        "vertexColorsMaskEnabledChanged",
        "vertexColorRedMaskChanged",
        "vertexColorGreenMaskChanged",
        "vertexColorBlueMaskChanged",
        "vertexColorAlphaMaskChanged",
        "setLighting",
        "setBlendMode",
        "setBaseColor",
        "setBaseColorMap",
        "setBaseColorSingleChannelEnabled",
        "setBaseColorChannel",
        "setSpecularSingleChannelEnabled",
        "specularSingleChannelEnabled",
        "setSpecularChannel",
        "setEmissiveSingleChannelEnabled",
        "emissiveSingleChannelEnabled",
        "setEmissiveChannel",
        "setEmissiveMap",
        "setEmissiveFactor",
        "setSpecularReflectionMap",
        "setSpecularMap",
        "setSpecularTint",
        "setSpecularAmount",
        "setRoughness",
        "setRoughnessMap",
        "setInvertOpacityMapValue",
        "setOpacity",
        "setOpacityMap",
        "setNormalMap",
        "setMetalness",
        "metalnessAmount",
        "setMetalnessMap",
        "setNormalStrength",
        "setOcclusionMap",
        "setOcclusionAmount",
        "setAlphaMode",
        "setAlphaCutoff",
        "setMetalnessChannel",
        "setRoughnessChannel",
        "setOpacityChannel",
        "setOcclusionChannel",
        "setPointSize",
        "size",
        "setLineWidth",
        "width",
        "setHeightMap",
        "setHeightChannel",
        "setHeightAmount",
        "setMinHeightMapSamples",
        "setMaxHeightMapSamples",
        "setClearcoatAmount",
        "newClearcoatAmount",
        "setClearcoatMap",
        "newClearcoatMap",
        "setClearcoatChannel",
        "newClearcoatChannel",
        "setClearcoatRoughnessAmount",
        "newClearcoatRoughnessAmount",
        "setClearcoatRoughnessChannel",
        "newClearcoatRoughnessChannel",
        "setClearcoatRoughnessMap",
        "newClearcoatRoughnessMap",
        "setClearcoatNormalMap",
        "newClearcoatNormalMap",
        "setClearcoatNormalStrength",
        "setTransmissionFactor",
        "newTransmissionFactor",
        "setTransmissionMap",
        "newTransmissionMap",
        "setTransmissionChannel",
        "newTransmissionChannel",
        "setThicknessFactor",
        "newThicknessFactor",
        "setThicknessMap",
        "newThicknessMap",
        "setThicknessChannel",
        "newThicknessChannel",
        "setAttenuationDistance",
        "newAttenuationDistance",
        "setAttenuationColor",
        "newAttenuationColor",
        "setIndexOfRefraction",
        "setFresnelScaleBiasEnabled",
        "fresnelScaleBias",
        "setFresnelScale",
        "setFresnelBias",
        "setFresnelPower",
        "setClearcoatFresnelScaleBiasEnabled",
        "clearcoatFresnelScaleBias",
        "setClearcoatFresnelScale",
        "setClearcoatFresnelBias",
        "setClearcoatFresnelPower",
        "setVertexColorsEnabled",
        "setVertexColorsMaskEnabled",
        "vertexColorsMaskEnabled",
        "setVertexColorRedMask",
        "VertexColorMaskFlags",
        "vertexColorRedMask",
        "setVertexColorGreenMask",
        "vertexColorGreenMask",
        "setVertexColorBlueMask",
        "vertexColorBlueMask",
        "setVertexColorAlphaMask",
        "vertexColorAlphaMask",
        "Lighting",
        "BlendMode",
        "baseColorChannel",
        "metalnessChannel",
        "specularChannel",
        "roughnessChannel",
        "emissiveChannel",
        "opacityChannel",
        "occlusionChannel",
        "AlphaMode",
        "pointSize",
        "lineWidth",
        "heightChannel",
        "minHeightMapSamples",
        "maxHeightMapSamples",
        "clearcoatAmount",
        "clearcoatMap",
        "clearcoatChannel",
        "clearcoatRoughnessAmount",
        "clearcoatRoughnessChannel",
        "clearcoatRoughnessMap",
        "clearcoatNormalMap",
        "transmissionFactor",
        "transmissionMap",
        "transmissionChannel",
        "thicknessFactor",
        "thicknessMap",
        "thicknessChannel",
        "attenuationDistance",
        "attenuationColor",
        "NoLighting",
        "FragmentLighting",
        "SourceOver",
        "Screen",
        "Multiply",
        "Default",
        "Mask",
        "Blend",
        "Opaque",
        "VertexColorMask",
        "NoMask",
        "RoughnessMask",
        "NormalStrengthMask",
        "SpecularAmountMask",
        "ClearcoatAmountMask",
        "ClearcoatRoughnessAmountMask",
        "ClearcoatNormalStrengthMask",
        "HeightAmountMask",
        "MetalnessMask",
        "OcclusionAmountMask",
        "ThicknessFactorMask",
        "TransmissionFactorMask"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'lightingChanged'
        QtMocHelpers::SignalData<void(QQuick3DPrincipledMaterial::Lighting)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'blendModeChanged'
        QtMocHelpers::SignalData<void(QQuick3DPrincipledMaterial::BlendMode)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'baseColorChanged'
        QtMocHelpers::SignalData<void(QColor)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'baseColorMapChanged'
        QtMocHelpers::SignalData<void(QQuick3DTexture *)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Signal 'baseColorSingleChannelEnabledChanged'
        QtMocHelpers::RevisionedSignalData<void(bool)>(16, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Signal 'baseColorChannelChanged'
        QtMocHelpers::RevisionedSignalData<void(QQuick3DMaterial::TextureChannelMapping)>(18, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'specularSingleChannelEnabledChanged'
        QtMocHelpers::RevisionedSignalData<void(bool)>(21, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Signal 'specularChannelChanged'
        QtMocHelpers::RevisionedSignalData<void(QQuick3DMaterial::TextureChannelMapping)>(23, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'emissiveSingleChannelEnabledChanged'
        QtMocHelpers::RevisionedSignalData<void(bool)>(24, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Signal 'emissiveChannelChanged'
        QtMocHelpers::RevisionedSignalData<void(QQuick3DMaterial::TextureChannelMapping)>(26, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'emissiveMapChanged'
        QtMocHelpers::SignalData<void(QQuick3DTexture *)>(27, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 28 },
        }}),
        // Signal 'emissiveFactorChanged'
        QtMocHelpers::SignalData<void(QVector3D)>(29, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Signal 'specularReflectionMapChanged'
        QtMocHelpers::SignalData<void(QQuick3DTexture *)>(32, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 33 },
        }}),
        // Signal 'specularMapChanged'
        QtMocHelpers::SignalData<void(QQuick3DTexture *)>(34, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 35 },
        }}),
        // Signal 'specularTintChanged'
        QtMocHelpers::SignalData<void(float)>(36, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 37 },
        }}),
        // Signal 'specularAmountChanged'
        QtMocHelpers::SignalData<void(float)>(38, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 39 },
        }}),
        // Signal 'roughnessChanged'
        QtMocHelpers::SignalData<void(float)>(40, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 41 },
        }}),
        // Signal 'roughnessMapChanged'
        QtMocHelpers::SignalData<void(QQuick3DTexture *)>(42, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 43 },
        }}),
        // Signal 'invertOpacityMapValueChanged'
        QtMocHelpers::RevisionedSignalData<void(bool)>(44, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Bool, 45 },
        }}),
        // Signal 'opacityChanged'
        QtMocHelpers::SignalData<void(float)>(46, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 47 },
        }}),
        // Signal 'opacityMapChanged'
        QtMocHelpers::SignalData<void(QQuick3DTexture *)>(48, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 49 },
        }}),
        // Signal 'normalMapChanged'
        QtMocHelpers::SignalData<void(QQuick3DTexture *)>(50, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 51 },
        }}),
        // Signal 'metalnessChanged'
        QtMocHelpers::SignalData<void(float)>(52, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 53 },
        }}),
        // Signal 'metalnessMapChanged'
        QtMocHelpers::SignalData<void(QQuick3DTexture *)>(54, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 55 },
        }}),
        // Signal 'normalStrengthChanged'
        QtMocHelpers::SignalData<void(float)>(56, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 57 },
        }}),
        // Signal 'occlusionMapChanged'
        QtMocHelpers::SignalData<void(QQuick3DTexture *)>(58, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 59 },
        }}),
        // Signal 'occlusionAmountChanged'
        QtMocHelpers::SignalData<void(float)>(60, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 61 },
        }}),
        // Signal 'alphaModeChanged'
        QtMocHelpers::SignalData<void(QQuick3DPrincipledMaterial::AlphaMode)>(62, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 63, 64 },
        }}),
        // Signal 'alphaCutoffChanged'
        QtMocHelpers::SignalData<void(float)>(65, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 66 },
        }}),
        // Signal 'metalnessChannelChanged'
        QtMocHelpers::SignalData<void(QQuick3DMaterial::TextureChannelMapping)>(67, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'roughnessChannelChanged'
        QtMocHelpers::SignalData<void(QQuick3DMaterial::TextureChannelMapping)>(68, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'opacityChannelChanged'
        QtMocHelpers::SignalData<void(QQuick3DMaterial::TextureChannelMapping)>(69, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'occlusionChannelChanged'
        QtMocHelpers::SignalData<void(QQuick3DMaterial::TextureChannelMapping)>(70, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'pointSizeChanged'
        QtMocHelpers::SignalData<void()>(71, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lineWidthChanged'
        QtMocHelpers::SignalData<void()>(72, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'heightMapChanged'
        QtMocHelpers::RevisionedSignalData<void(QQuick3DTexture *)>(73, 4, QMC::AccessPublic, 0x602, QMetaType::Void, {{
            { 0x80000000 | 14, 74 },
        }}),
        // Signal 'heightChannelChanged'
        QtMocHelpers::RevisionedSignalData<void(QQuick3DMaterial::TextureChannelMapping)>(75, 4, QMC::AccessPublic, 0x602, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'heightAmountChanged'
        QtMocHelpers::RevisionedSignalData<void(float)>(76, 4, QMC::AccessPublic, 0x602, QMetaType::Void, {{
            { QMetaType::Float, 77 },
        }}),
        // Signal 'minHeightMapSamplesChanged'
        QtMocHelpers::RevisionedSignalData<void(int)>(78, 4, QMC::AccessPublic, 0x602, QMetaType::Void, {{
            { QMetaType::Int, 79 },
        }}),
        // Signal 'maxHeightMapSamplesChanged'
        QtMocHelpers::RevisionedSignalData<void(int)>(80, 4, QMC::AccessPublic, 0x602, QMetaType::Void, {{
            { QMetaType::Int, 79 },
        }}),
        // Signal 'clearcoatAmountChanged'
        QtMocHelpers::RevisionedSignalData<void(float)>(81, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { QMetaType::Float, 82 },
        }}),
        // Signal 'clearcoatMapChanged'
        QtMocHelpers::RevisionedSignalData<void(QQuick3DTexture *)>(83, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { 0x80000000 | 14, 84 },
        }}),
        // Signal 'clearcoatChannelChanged'
        QtMocHelpers::RevisionedSignalData<void(QQuick3DMaterial::TextureChannelMapping)>(85, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'clearcoatRoughnessAmountChanged'
        QtMocHelpers::RevisionedSignalData<void(float)>(86, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { QMetaType::Float, 82 },
        }}),
        // Signal 'clearcoatRoughnessChannelChanged'
        QtMocHelpers::RevisionedSignalData<void(QQuick3DMaterial::TextureChannelMapping)>(87, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'clearcoatRoughnessMapChanged'
        QtMocHelpers::RevisionedSignalData<void(QQuick3DTexture *)>(88, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { 0x80000000 | 14, 84 },
        }}),
        // Signal 'clearcoatNormalMapChanged'
        QtMocHelpers::RevisionedSignalData<void(QQuick3DTexture *)>(89, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { 0x80000000 | 14, 84 },
        }}),
        // Signal 'clearcoatNormalStrengthChanged'
        QtMocHelpers::RevisionedSignalData<void(float)>(90, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 91 },
        }}),
        // Signal 'transmissionFactorChanged'
        QtMocHelpers::RevisionedSignalData<void(float)>(92, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { QMetaType::Float, 82 },
        }}),
        // Signal 'transmissionMapChanged'
        QtMocHelpers::RevisionedSignalData<void(QQuick3DTexture *)>(93, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { 0x80000000 | 14, 84 },
        }}),
        // Signal 'transmissionChannelChanged'
        QtMocHelpers::RevisionedSignalData<void(QQuick3DMaterial::TextureChannelMapping)>(94, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'thicknessFactorChanged'
        QtMocHelpers::RevisionedSignalData<void(float)>(95, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { QMetaType::Float, 82 },
        }}),
        // Signal 'thicknessMapChanged'
        QtMocHelpers::RevisionedSignalData<void(QQuick3DTexture *)>(96, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { 0x80000000 | 14, 84 },
        }}),
        // Signal 'thicknessChannelChanged'
        QtMocHelpers::RevisionedSignalData<void(QQuick3DMaterial::TextureChannelMapping)>(97, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'attenuationDistanceChanged'
        QtMocHelpers::RevisionedSignalData<void(float)>(98, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { QMetaType::Float, 99 },
        }}),
        // Signal 'attenuationColorChanged'
        QtMocHelpers::RevisionedSignalData<void(QColor)>(100, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { 0x80000000 | 11, 101 },
        }}),
        // Signal 'indexOfRefractionChanged'
        QtMocHelpers::RevisionedSignalData<void(float)>(102, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { QMetaType::Float, 103 },
        }}),
        // Signal 'fresnelScaleBiasEnabledChanged'
        QtMocHelpers::RevisionedSignalData<void(bool)>(104, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Bool, 105 },
        }}),
        // Signal 'fresnelScaleChanged'
        QtMocHelpers::RevisionedSignalData<void(float)>(106, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 107 },
        }}),
        // Signal 'fresnelBiasChanged'
        QtMocHelpers::RevisionedSignalData<void(float)>(108, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 109 },
        }}),
        // Signal 'fresnelPowerChanged'
        QtMocHelpers::RevisionedSignalData<void(float)>(110, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 111 },
        }}),
        // Signal 'clearcoatFresnelScaleBiasEnabledChanged'
        QtMocHelpers::RevisionedSignalData<void(bool)>(112, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Bool, 113 },
        }}),
        // Signal 'clearcoatFresnelScaleChanged'
        QtMocHelpers::RevisionedSignalData<void(float)>(114, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 115 },
        }}),
        // Signal 'clearcoatFresnelBiasChanged'
        QtMocHelpers::RevisionedSignalData<void(float)>(116, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 117 },
        }}),
        // Signal 'clearcoatFresnelPowerChanged'
        QtMocHelpers::RevisionedSignalData<void(float)>(118, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 119 },
        }}),
        // Signal 'vertexColorsEnabledChanged'
        QtMocHelpers::RevisionedSignalData<void(bool)>(120, 4, QMC::AccessPublic, 0x605, QMetaType::Void, {{
            { QMetaType::Bool, 121 },
        }}),
        // Signal 'vertexColorsMaskEnabledChanged'
        QtMocHelpers::RevisionedSignalData<void()>(122, 4, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'vertexColorRedMaskChanged'
        QtMocHelpers::RevisionedSignalData<void()>(123, 4, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'vertexColorGreenMaskChanged'
        QtMocHelpers::RevisionedSignalData<void()>(124, 4, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'vertexColorBlueMaskChanged'
        QtMocHelpers::RevisionedSignalData<void()>(125, 4, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'vertexColorAlphaMaskChanged'
        QtMocHelpers::RevisionedSignalData<void()>(126, 4, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Slot 'setLighting'
        QtMocHelpers::SlotData<void(QQuick3DPrincipledMaterial::Lighting)>(127, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'setBlendMode'
        QtMocHelpers::SlotData<void(QQuick3DPrincipledMaterial::BlendMode)>(128, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'setBaseColor'
        QtMocHelpers::SlotData<void(QColor)>(129, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'setBaseColorMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(130, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'setBaseColorSingleChannelEnabled'
        QtMocHelpers::RevisionedSlotData<void(bool)>(131, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'setBaseColorChannel'
        QtMocHelpers::RevisionedSlotData<void(QQuick3DMaterial::TextureChannelMapping)>(132, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'setSpecularSingleChannelEnabled'
        QtMocHelpers::RevisionedSlotData<void(bool)>(133, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Bool, 134 },
        }}),
        // Slot 'setSpecularChannel'
        QtMocHelpers::RevisionedSlotData<void(QQuick3DMaterial::TextureChannelMapping)>(135, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'setEmissiveSingleChannelEnabled'
        QtMocHelpers::RevisionedSlotData<void(bool)>(136, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Bool, 137 },
        }}),
        // Slot 'setEmissiveChannel'
        QtMocHelpers::RevisionedSlotData<void(QQuick3DMaterial::TextureChannelMapping)>(138, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'setEmissiveMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(139, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 28 },
        }}),
        // Slot 'setEmissiveFactor'
        QtMocHelpers::SlotData<void(QVector3D)>(140, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'setSpecularReflectionMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(141, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 33 },
        }}),
        // Slot 'setSpecularMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(142, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 35 },
        }}),
        // Slot 'setSpecularTint'
        QtMocHelpers::SlotData<void(float)>(143, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 37 },
        }}),
        // Slot 'setSpecularAmount'
        QtMocHelpers::SlotData<void(float)>(144, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 39 },
        }}),
        // Slot 'setRoughness'
        QtMocHelpers::SlotData<void(float)>(145, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 41 },
        }}),
        // Slot 'setRoughnessMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(146, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 43 },
        }}),
        // Slot 'setInvertOpacityMapValue'
        QtMocHelpers::RevisionedSlotData<void(bool)>(147, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Bool, 45 },
        }}),
        // Slot 'setOpacity'
        QtMocHelpers::SlotData<void(float)>(148, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 47 },
        }}),
        // Slot 'setOpacityMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(149, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 49 },
        }}),
        // Slot 'setNormalMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(150, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 51 },
        }}),
        // Slot 'setMetalness'
        QtMocHelpers::SlotData<void(float)>(151, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 152 },
        }}),
        // Slot 'setMetalnessMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(153, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 55 },
        }}),
        // Slot 'setNormalStrength'
        QtMocHelpers::SlotData<void(float)>(154, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 57 },
        }}),
        // Slot 'setOcclusionMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(155, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 59 },
        }}),
        // Slot 'setOcclusionAmount'
        QtMocHelpers::SlotData<void(float)>(156, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 61 },
        }}),
        // Slot 'setAlphaMode'
        QtMocHelpers::SlotData<void(QQuick3DPrincipledMaterial::AlphaMode)>(157, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 63, 64 },
        }}),
        // Slot 'setAlphaCutoff'
        QtMocHelpers::SlotData<void(float)>(158, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 66 },
        }}),
        // Slot 'setMetalnessChannel'
        QtMocHelpers::SlotData<void(QQuick3DMaterial::TextureChannelMapping)>(159, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'setRoughnessChannel'
        QtMocHelpers::SlotData<void(QQuick3DMaterial::TextureChannelMapping)>(160, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'setOpacityChannel'
        QtMocHelpers::SlotData<void(QQuick3DMaterial::TextureChannelMapping)>(161, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'setOcclusionChannel'
        QtMocHelpers::SlotData<void(QQuick3DMaterial::TextureChannelMapping)>(162, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'setPointSize'
        QtMocHelpers::SlotData<void(float)>(163, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 164 },
        }}),
        // Slot 'setLineWidth'
        QtMocHelpers::SlotData<void(float)>(165, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 166 },
        }}),
        // Slot 'setHeightMap'
        QtMocHelpers::RevisionedSlotData<void(QQuick3DTexture *)>(167, 4, QMC::AccessPublic, 0x602, QMetaType::Void, {{
            { 0x80000000 | 14, 74 },
        }}),
        // Slot 'setHeightChannel'
        QtMocHelpers::RevisionedSlotData<void(QQuick3DMaterial::TextureChannelMapping)>(168, 4, QMC::AccessPublic, 0x602, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'setHeightAmount'
        QtMocHelpers::RevisionedSlotData<void(float)>(169, 4, QMC::AccessPublic, 0x602, QMetaType::Void, {{
            { QMetaType::Float, 77 },
        }}),
        // Slot 'setMinHeightMapSamples'
        QtMocHelpers::RevisionedSlotData<void(int)>(170, 4, QMC::AccessPublic, 0x602, QMetaType::Void, {{
            { QMetaType::Int, 79 },
        }}),
        // Slot 'setMaxHeightMapSamples'
        QtMocHelpers::RevisionedSlotData<void(int)>(171, 4, QMC::AccessPublic, 0x602, QMetaType::Void, {{
            { QMetaType::Int, 79 },
        }}),
        // Slot 'setClearcoatAmount'
        QtMocHelpers::RevisionedSlotData<void(float)>(172, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { QMetaType::Float, 173 },
        }}),
        // Slot 'setClearcoatMap'
        QtMocHelpers::RevisionedSlotData<void(QQuick3DTexture *)>(174, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { 0x80000000 | 14, 175 },
        }}),
        // Slot 'setClearcoatChannel'
        QtMocHelpers::RevisionedSlotData<void(QQuick3DMaterial::TextureChannelMapping)>(176, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { 0x80000000 | 19, 177 },
        }}),
        // Slot 'setClearcoatRoughnessAmount'
        QtMocHelpers::RevisionedSlotData<void(float)>(178, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { QMetaType::Float, 179 },
        }}),
        // Slot 'setClearcoatRoughnessChannel'
        QtMocHelpers::RevisionedSlotData<void(QQuick3DMaterial::TextureChannelMapping)>(180, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { 0x80000000 | 19, 181 },
        }}),
        // Slot 'setClearcoatRoughnessMap'
        QtMocHelpers::RevisionedSlotData<void(QQuick3DTexture *)>(182, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { 0x80000000 | 14, 183 },
        }}),
        // Slot 'setClearcoatNormalMap'
        QtMocHelpers::RevisionedSlotData<void(QQuick3DTexture *)>(184, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { 0x80000000 | 14, 185 },
        }}),
        // Slot 'setClearcoatNormalStrength'
        QtMocHelpers::RevisionedSlotData<void(float)>(186, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 91 },
        }}),
        // Slot 'setTransmissionFactor'
        QtMocHelpers::RevisionedSlotData<void(float)>(187, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { QMetaType::Float, 188 },
        }}),
        // Slot 'setTransmissionMap'
        QtMocHelpers::RevisionedSlotData<void(QQuick3DTexture *)>(189, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { 0x80000000 | 14, 190 },
        }}),
        // Slot 'setTransmissionChannel'
        QtMocHelpers::RevisionedSlotData<void(QQuick3DMaterial::TextureChannelMapping)>(191, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { 0x80000000 | 19, 192 },
        }}),
        // Slot 'setThicknessFactor'
        QtMocHelpers::RevisionedSlotData<void(float)>(193, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { QMetaType::Float, 194 },
        }}),
        // Slot 'setThicknessMap'
        QtMocHelpers::RevisionedSlotData<void(QQuick3DTexture *)>(195, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { 0x80000000 | 14, 196 },
        }}),
        // Slot 'setThicknessChannel'
        QtMocHelpers::RevisionedSlotData<void(const QQuick3DMaterial::TextureChannelMapping &)>(197, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { 0x80000000 | 19, 198 },
        }}),
        // Slot 'setAttenuationDistance'
        QtMocHelpers::RevisionedSlotData<void(float)>(199, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { QMetaType::Float, 200 },
        }}),
        // Slot 'setAttenuationColor'
        QtMocHelpers::RevisionedSlotData<void(const QColor &)>(201, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { 0x80000000 | 11, 202 },
        }}),
        // Slot 'setIndexOfRefraction'
        QtMocHelpers::RevisionedSlotData<void(float)>(203, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { QMetaType::Float, 103 },
        }}),
        // Slot 'setFresnelScaleBiasEnabled'
        QtMocHelpers::RevisionedSlotData<void(bool)>(204, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Bool, 205 },
        }}),
        // Slot 'setFresnelScale'
        QtMocHelpers::RevisionedSlotData<void(float)>(206, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 107 },
        }}),
        // Slot 'setFresnelBias'
        QtMocHelpers::RevisionedSlotData<void(float)>(207, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 109 },
        }}),
        // Slot 'setFresnelPower'
        QtMocHelpers::RevisionedSlotData<void(float)>(208, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 111 },
        }}),
        // Slot 'setClearcoatFresnelScaleBiasEnabled'
        QtMocHelpers::RevisionedSlotData<void(bool)>(209, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Bool, 210 },
        }}),
        // Slot 'setClearcoatFresnelScale'
        QtMocHelpers::RevisionedSlotData<void(float)>(211, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 115 },
        }}),
        // Slot 'setClearcoatFresnelBias'
        QtMocHelpers::RevisionedSlotData<void(float)>(212, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 117 },
        }}),
        // Slot 'setClearcoatFresnelPower'
        QtMocHelpers::RevisionedSlotData<void(float)>(213, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 119 },
        }}),
        // Slot 'setVertexColorsEnabled'
        QtMocHelpers::RevisionedSlotData<void(bool)>(214, 4, QMC::AccessPublic, 0x605, QMetaType::Void, {{
            { QMetaType::Bool, 121 },
        }}),
        // Slot 'setVertexColorsMaskEnabled'
        QtMocHelpers::RevisionedSlotData<void(bool)>(215, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Bool, 216 },
        }}),
        // Slot 'setVertexColorRedMask'
        QtMocHelpers::RevisionedSlotData<void(VertexColorMaskFlags)>(217, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { 0x80000000 | 218, 219 },
        }}),
        // Slot 'setVertexColorGreenMask'
        QtMocHelpers::RevisionedSlotData<void(VertexColorMaskFlags)>(220, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { 0x80000000 | 218, 221 },
        }}),
        // Slot 'setVertexColorBlueMask'
        QtMocHelpers::RevisionedSlotData<void(VertexColorMaskFlags)>(222, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { 0x80000000 | 218, 223 },
        }}),
        // Slot 'setVertexColorAlphaMask'
        QtMocHelpers::RevisionedSlotData<void(VertexColorMaskFlags)>(224, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { 0x80000000 | 218, 225 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'lighting'
        QtMocHelpers::PropertyData<enum Lighting>(6, 0x80000000 | 226, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'blendMode'
        QtMocHelpers::PropertyData<enum BlendMode>(9, 0x80000000 | 227, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'baseColor'
        QtMocHelpers::PropertyData<QColor>(12, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'baseColorMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(15, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'baseColorSingleChannelEnabled'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4, 0x608),
        // property 'baseColorChannel'
        QtMocHelpers::PropertyData<QQuick3DMaterial::TextureChannelMapping>(228, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5, 0x608),
        // property 'metalness'
        QtMocHelpers::PropertyData<float>(53, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 22),
        // property 'metalnessMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(55, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 23),
        // property 'metalnessChannel'
        QtMocHelpers::PropertyData<QQuick3DMaterial::TextureChannelMapping>(229, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 29),
        // property 'specularAmount'
        QtMocHelpers::PropertyData<float>(39, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'specularMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(35, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 13),
        // property 'specularTint'
        QtMocHelpers::PropertyData<float>(37, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'specularSingleChannelEnabled'
        QtMocHelpers::PropertyData<bool>(134, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6, 0x608),
        // property 'specularChannel'
        QtMocHelpers::PropertyData<QQuick3DMaterial::TextureChannelMapping>(230, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7, 0x608),
        // property 'roughness'
        QtMocHelpers::PropertyData<float>(41, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'roughnessMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(43, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 17),
        // property 'roughnessChannel'
        QtMocHelpers::PropertyData<QQuick3DMaterial::TextureChannelMapping>(231, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 30),
        // property 'emissiveFactor'
        QtMocHelpers::PropertyData<QVector3D>(31, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 11),
        // property 'emissiveMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(28, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 10),
        // property 'emissiveSingleChannelEnabled'
        QtMocHelpers::PropertyData<bool>(137, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8, 0x608),
        // property 'emissiveChannel'
        QtMocHelpers::PropertyData<QQuick3DMaterial::TextureChannelMapping>(232, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 9, 0x608),
        // property 'invertOpacityMapValue'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18, 0x608),
        // property 'opacity'
        QtMocHelpers::PropertyData<float>(47, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'opacityMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(49, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 20),
        // property 'opacityChannel'
        QtMocHelpers::PropertyData<QQuick3DMaterial::TextureChannelMapping>(233, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 31),
        // property 'normalMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(51, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 21),
        // property 'normalStrength'
        QtMocHelpers::PropertyData<float>(57, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 24),
        // property 'specularReflectionMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(33, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 12),
        // property 'occlusionMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(59, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 25),
        // property 'occlusionChannel'
        QtMocHelpers::PropertyData<QQuick3DMaterial::TextureChannelMapping>(234, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 32),
        // property 'occlusionAmount'
        QtMocHelpers::PropertyData<float>(61, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 26),
        // property 'alphaMode'
        QtMocHelpers::PropertyData<enum AlphaMode>(64, 0x80000000 | 235, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 27),
        // property 'alphaCutoff'
        QtMocHelpers::PropertyData<float>(66, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 28),
        // property 'pointSize'
        QtMocHelpers::PropertyData<float>(236, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 33),
        // property 'lineWidth'
        QtMocHelpers::PropertyData<float>(237, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 34),
        // property 'heightMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(74, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 35, 0x602),
        // property 'heightChannel'
        QtMocHelpers::PropertyData<QQuick3DMaterial::TextureChannelMapping>(238, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 36, 0x602),
        // property 'heightAmount'
        QtMocHelpers::PropertyData<float>(77, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 37, 0x602),
        // property 'minHeightMapSamples'
        QtMocHelpers::PropertyData<int>(239, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 38, 0x602),
        // property 'maxHeightMapSamples'
        QtMocHelpers::PropertyData<int>(240, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 39, 0x602),
        // property 'clearcoatAmount'
        QtMocHelpers::PropertyData<float>(241, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 40, 0x603),
        // property 'clearcoatMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(242, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 41, 0x603),
        // property 'clearcoatChannel'
        QtMocHelpers::PropertyData<QQuick3DMaterial::TextureChannelMapping>(243, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 42, 0x603),
        // property 'clearcoatRoughnessAmount'
        QtMocHelpers::PropertyData<float>(244, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 43, 0x603),
        // property 'clearcoatRoughnessChannel'
        QtMocHelpers::PropertyData<QQuick3DMaterial::TextureChannelMapping>(245, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 44, 0x603),
        // property 'clearcoatRoughnessMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(246, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 45, 0x603),
        // property 'clearcoatNormalMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(247, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 46, 0x603),
        // property 'clearcoatNormalStrength'
        QtMocHelpers::PropertyData<float>(91, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 47, 0x608),
        // property 'transmissionFactor'
        QtMocHelpers::PropertyData<float>(248, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 48),
        // property 'transmissionMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(249, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 49),
        // property 'transmissionChannel'
        QtMocHelpers::PropertyData<QQuick3DMaterial::TextureChannelMapping>(250, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 50),
        // property 'thicknessFactor'
        QtMocHelpers::PropertyData<float>(251, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 51, 0x603),
        // property 'thicknessMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(252, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 52, 0x603),
        // property 'thicknessChannel'
        QtMocHelpers::PropertyData<QQuick3DMaterial::TextureChannelMapping>(253, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 53, 0x603),
        // property 'attenuationDistance'
        QtMocHelpers::PropertyData<float>(254, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 54, 0x603),
        // property 'attenuationColor'
        QtMocHelpers::PropertyData<QColor>(255, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 55, 0x603),
        // property 'indexOfRefraction'
        QtMocHelpers::PropertyData<float>(103, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 56, 0x603),
        // property 'vertexColorsEnabled'
        QtMocHelpers::PropertyData<bool>(121, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 65, 0x605),
        // property 'fresnelScaleBiasEnabled'
        QtMocHelpers::PropertyData<bool>(105, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 57, 0x608),
        // property 'fresnelScale'
        QtMocHelpers::PropertyData<float>(107, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 58, 0x608),
        // property 'fresnelBias'
        QtMocHelpers::PropertyData<float>(109, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 59, 0x608),
        // property 'fresnelPower'
        QtMocHelpers::PropertyData<float>(111, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 60, 0x608),
        // property 'clearcoatFresnelScaleBiasEnabled'
        QtMocHelpers::PropertyData<bool>(113, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 61, 0x608),
        // property 'clearcoatFresnelScale'
        QtMocHelpers::PropertyData<float>(115, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 62, 0x608),
        // property 'clearcoatFresnelBias'
        QtMocHelpers::PropertyData<float>(117, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 63, 0x608),
        // property 'clearcoatFresnelPower'
        QtMocHelpers::PropertyData<float>(119, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 64, 0x608),
        // property 'vertexColorsMaskEnabled'
        QtMocHelpers::PropertyData<bool>(216, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 66, 0x608),
        // property 'vertexColorRedMask'
        QtMocHelpers::PropertyData<VertexColorMaskFlags>(219, 0x80000000 | 218, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 67, 0x608),
        // property 'vertexColorGreenMask'
        QtMocHelpers::PropertyData<VertexColorMaskFlags>(221, 0x80000000 | 218, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 68, 0x608),
        // property 'vertexColorBlueMask'
        QtMocHelpers::PropertyData<VertexColorMaskFlags>(223, 0x80000000 | 218, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 69, 0x608),
        // property 'vertexColorAlphaMask'
        QtMocHelpers::PropertyData<VertexColorMaskFlags>(225, 0x80000000 | 218, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 70, 0x608),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Lighting'
        QtMocHelpers::EnumData<enum Lighting>(226, 226, QMC::EnumFlags{}).add({
            {  256, Lighting::NoLighting },
            {  257, Lighting::FragmentLighting },
        }),
        // enum 'BlendMode'
        QtMocHelpers::EnumData<enum BlendMode>(227, 227, QMC::EnumFlags{}).add({
            {  258, BlendMode::SourceOver },
            {  259, BlendMode::Screen },
            {  260, BlendMode::Multiply },
        }),
        // enum 'AlphaMode'
        QtMocHelpers::EnumData<enum AlphaMode>(235, 235, QMC::EnumFlags{}).add({
            {  261, AlphaMode::Default },
            {  262, AlphaMode::Mask },
            {  263, AlphaMode::Blend },
            {  264, AlphaMode::Opaque },
        }),
        // enum 'VertexColorMask'
        QtMocHelpers::EnumData<enum VertexColorMask>(265, 265, QMC::EnumFlags{}).add({
            {  266, VertexColorMask::NoMask },
            {  267, VertexColorMask::RoughnessMask },
            {  268, VertexColorMask::NormalStrengthMask },
            {  269, VertexColorMask::SpecularAmountMask },
            {  270, VertexColorMask::ClearcoatAmountMask },
            {  271, VertexColorMask::ClearcoatRoughnessAmountMask },
            {  272, VertexColorMask::ClearcoatNormalStrengthMask },
            {  273, VertexColorMask::HeightAmountMask },
            {  274, VertexColorMask::MetalnessMask },
            {  275, VertexColorMask::OcclusionAmountMask },
            {  276, VertexColorMask::ThicknessFactorMask },
            {  277, VertexColorMask::TransmissionFactorMask },
        }),
        // flag 'VertexColorMaskFlags'
        QtMocHelpers::EnumData<VertexColorMaskFlags>(218, 265, QMC::EnumIsFlag).add({
            {  266, VertexColorMask::NoMask },
            {  267, VertexColorMask::RoughnessMask },
            {  268, VertexColorMask::NormalStrengthMask },
            {  269, VertexColorMask::SpecularAmountMask },
            {  270, VertexColorMask::ClearcoatAmountMask },
            {  271, VertexColorMask::ClearcoatRoughnessAmountMask },
            {  272, VertexColorMask::ClearcoatNormalStrengthMask },
            {  273, VertexColorMask::HeightAmountMask },
            {  274, VertexColorMask::MetalnessMask },
            {  275, VertexColorMask::OcclusionAmountMask },
            {  276, VertexColorMask::ThicknessFactorMask },
            {  277, VertexColorMask::TransmissionFactorMask },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DPrincipledMaterial, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN26QQuick3DPrincipledMaterialE[] = {
    QMetaObject::SuperData::link<QQuick3DMaterial::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject QQuick3DPrincipledMaterial::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DMaterial::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26QQuick3DPrincipledMaterialE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26QQuick3DPrincipledMaterialE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN26QQuick3DPrincipledMaterialE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26QQuick3DPrincipledMaterialE_t>.metaTypes,
    nullptr
} };

void QQuick3DPrincipledMaterial::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DPrincipledMaterial *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->lightingChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DPrincipledMaterial::Lighting>>(_a[1]))); break;
        case 1: _t->blendModeChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DPrincipledMaterial::BlendMode>>(_a[1]))); break;
        case 2: _t->baseColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 3: _t->baseColorMapChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 4: _t->baseColorSingleChannelEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->baseColorChannelChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 6: _t->specularSingleChannelEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->specularChannelChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 8: _t->emissiveSingleChannelEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->emissiveChannelChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 10: _t->emissiveMapChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 11: _t->emissiveFactorChanged((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 12: _t->specularReflectionMapChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 13: _t->specularMapChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 14: _t->specularTintChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 15: _t->specularAmountChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 16: _t->roughnessChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 17: _t->roughnessMapChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 18: _t->invertOpacityMapValueChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->opacityChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 20: _t->opacityMapChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 21: _t->normalMapChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 22: _t->metalnessChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 23: _t->metalnessMapChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 24: _t->normalStrengthChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 25: _t->occlusionMapChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 26: _t->occlusionAmountChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 27: _t->alphaModeChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DPrincipledMaterial::AlphaMode>>(_a[1]))); break;
        case 28: _t->alphaCutoffChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 29: _t->metalnessChannelChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 30: _t->roughnessChannelChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 31: _t->opacityChannelChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 32: _t->occlusionChannelChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 33: _t->pointSizeChanged(); break;
        case 34: _t->lineWidthChanged(); break;
        case 35: _t->heightMapChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 36: _t->heightChannelChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 37: _t->heightAmountChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 38: _t->minHeightMapSamplesChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 39: _t->maxHeightMapSamplesChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 40: _t->clearcoatAmountChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 41: _t->clearcoatMapChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 42: _t->clearcoatChannelChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 43: _t->clearcoatRoughnessAmountChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 44: _t->clearcoatRoughnessChannelChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 45: _t->clearcoatRoughnessMapChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 46: _t->clearcoatNormalMapChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 47: _t->clearcoatNormalStrengthChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 48: _t->transmissionFactorChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 49: _t->transmissionMapChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 50: _t->transmissionChannelChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 51: _t->thicknessFactorChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 52: _t->thicknessMapChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 53: _t->thicknessChannelChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 54: _t->attenuationDistanceChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 55: _t->attenuationColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 56: _t->indexOfRefractionChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 57: _t->fresnelScaleBiasEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 58: _t->fresnelScaleChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 59: _t->fresnelBiasChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 60: _t->fresnelPowerChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 61: _t->clearcoatFresnelScaleBiasEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 62: _t->clearcoatFresnelScaleChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 63: _t->clearcoatFresnelBiasChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 64: _t->clearcoatFresnelPowerChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 65: _t->vertexColorsEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 66: _t->vertexColorsMaskEnabledChanged(); break;
        case 67: _t->vertexColorRedMaskChanged(); break;
        case 68: _t->vertexColorGreenMaskChanged(); break;
        case 69: _t->vertexColorBlueMaskChanged(); break;
        case 70: _t->vertexColorAlphaMaskChanged(); break;
        case 71: _t->setLighting((*reinterpret_cast<std::add_pointer_t<QQuick3DPrincipledMaterial::Lighting>>(_a[1]))); break;
        case 72: _t->setBlendMode((*reinterpret_cast<std::add_pointer_t<QQuick3DPrincipledMaterial::BlendMode>>(_a[1]))); break;
        case 73: _t->setBaseColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 74: _t->setBaseColorMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 75: _t->setBaseColorSingleChannelEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 76: _t->setBaseColorChannel((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 77: _t->setSpecularSingleChannelEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 78: _t->setSpecularChannel((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 79: _t->setEmissiveSingleChannelEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 80: _t->setEmissiveChannel((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 81: _t->setEmissiveMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 82: _t->setEmissiveFactor((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 83: _t->setSpecularReflectionMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 84: _t->setSpecularMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 85: _t->setSpecularTint((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 86: _t->setSpecularAmount((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 87: _t->setRoughness((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 88: _t->setRoughnessMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 89: _t->setInvertOpacityMapValue((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 90: _t->setOpacity((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 91: _t->setOpacityMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 92: _t->setNormalMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 93: _t->setMetalness((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 94: _t->setMetalnessMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 95: _t->setNormalStrength((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 96: _t->setOcclusionMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 97: _t->setOcclusionAmount((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 98: _t->setAlphaMode((*reinterpret_cast<std::add_pointer_t<QQuick3DPrincipledMaterial::AlphaMode>>(_a[1]))); break;
        case 99: _t->setAlphaCutoff((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 100: _t->setMetalnessChannel((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 101: _t->setRoughnessChannel((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 102: _t->setOpacityChannel((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 103: _t->setOcclusionChannel((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 104: _t->setPointSize((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 105: _t->setLineWidth((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 106: _t->setHeightMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 107: _t->setHeightChannel((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 108: _t->setHeightAmount((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 109: _t->setMinHeightMapSamples((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 110: _t->setMaxHeightMapSamples((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 111: _t->setClearcoatAmount((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 112: _t->setClearcoatMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 113: _t->setClearcoatChannel((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 114: _t->setClearcoatRoughnessAmount((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 115: _t->setClearcoatRoughnessChannel((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 116: _t->setClearcoatRoughnessMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 117: _t->setClearcoatNormalMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 118: _t->setClearcoatNormalStrength((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 119: _t->setTransmissionFactor((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 120: _t->setTransmissionMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 121: _t->setTransmissionChannel((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 122: _t->setThicknessFactor((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 123: _t->setThicknessMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 124: _t->setThicknessChannel((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 125: _t->setAttenuationDistance((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 126: _t->setAttenuationColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 127: _t->setIndexOfRefraction((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 128: _t->setFresnelScaleBiasEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 129: _t->setFresnelScale((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 130: _t->setFresnelBias((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 131: _t->setFresnelPower((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 132: _t->setClearcoatFresnelScaleBiasEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 133: _t->setClearcoatFresnelScale((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 134: _t->setClearcoatFresnelBias((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 135: _t->setClearcoatFresnelPower((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 136: _t->setVertexColorsEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 137: _t->setVertexColorsMaskEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 138: _t->setVertexColorRedMask((*reinterpret_cast<std::add_pointer_t<VertexColorMaskFlags>>(_a[1]))); break;
        case 139: _t->setVertexColorGreenMask((*reinterpret_cast<std::add_pointer_t<VertexColorMaskFlags>>(_a[1]))); break;
        case 140: _t->setVertexColorBlueMask((*reinterpret_cast<std::add_pointer_t<VertexColorMaskFlags>>(_a[1]))); break;
        case 141: _t->setVertexColorAlphaMask((*reinterpret_cast<std::add_pointer_t<VertexColorMaskFlags>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 41:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 45:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 46:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 49:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 52:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 74:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 81:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 83:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 84:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 88:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 91:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 92:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 94:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 96:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 106:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 112:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 116:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 117:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 120:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 123:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DPrincipledMaterial::Lighting )>(_a, &QQuick3DPrincipledMaterial::lightingChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DPrincipledMaterial::BlendMode )>(_a, &QQuick3DPrincipledMaterial::blendModeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QColor )>(_a, &QQuick3DPrincipledMaterial::baseColorChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DTexture * )>(_a, &QQuick3DPrincipledMaterial::baseColorMapChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(bool )>(_a, &QQuick3DPrincipledMaterial::baseColorSingleChannelEnabledChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DMaterial::TextureChannelMapping )>(_a, &QQuick3DPrincipledMaterial::baseColorChannelChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(bool )>(_a, &QQuick3DPrincipledMaterial::specularSingleChannelEnabledChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DMaterial::TextureChannelMapping )>(_a, &QQuick3DPrincipledMaterial::specularChannelChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(bool )>(_a, &QQuick3DPrincipledMaterial::emissiveSingleChannelEnabledChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DMaterial::TextureChannelMapping )>(_a, &QQuick3DPrincipledMaterial::emissiveChannelChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DTexture * )>(_a, &QQuick3DPrincipledMaterial::emissiveMapChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QVector3D )>(_a, &QQuick3DPrincipledMaterial::emissiveFactorChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DTexture * )>(_a, &QQuick3DPrincipledMaterial::specularReflectionMapChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DTexture * )>(_a, &QQuick3DPrincipledMaterial::specularMapChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(float )>(_a, &QQuick3DPrincipledMaterial::specularTintChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(float )>(_a, &QQuick3DPrincipledMaterial::specularAmountChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(float )>(_a, &QQuick3DPrincipledMaterial::roughnessChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DTexture * )>(_a, &QQuick3DPrincipledMaterial::roughnessMapChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(bool )>(_a, &QQuick3DPrincipledMaterial::invertOpacityMapValueChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(float )>(_a, &QQuick3DPrincipledMaterial::opacityChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DTexture * )>(_a, &QQuick3DPrincipledMaterial::opacityMapChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DTexture * )>(_a, &QQuick3DPrincipledMaterial::normalMapChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(float )>(_a, &QQuick3DPrincipledMaterial::metalnessChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DTexture * )>(_a, &QQuick3DPrincipledMaterial::metalnessMapChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(float )>(_a, &QQuick3DPrincipledMaterial::normalStrengthChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DTexture * )>(_a, &QQuick3DPrincipledMaterial::occlusionMapChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(float )>(_a, &QQuick3DPrincipledMaterial::occlusionAmountChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DPrincipledMaterial::AlphaMode )>(_a, &QQuick3DPrincipledMaterial::alphaModeChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(float )>(_a, &QQuick3DPrincipledMaterial::alphaCutoffChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DMaterial::TextureChannelMapping )>(_a, &QQuick3DPrincipledMaterial::metalnessChannelChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DMaterial::TextureChannelMapping )>(_a, &QQuick3DPrincipledMaterial::roughnessChannelChanged, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DMaterial::TextureChannelMapping )>(_a, &QQuick3DPrincipledMaterial::opacityChannelChanged, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DMaterial::TextureChannelMapping )>(_a, &QQuick3DPrincipledMaterial::occlusionChannelChanged, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)()>(_a, &QQuick3DPrincipledMaterial::pointSizeChanged, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)()>(_a, &QQuick3DPrincipledMaterial::lineWidthChanged, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DTexture * )>(_a, &QQuick3DPrincipledMaterial::heightMapChanged, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DMaterial::TextureChannelMapping )>(_a, &QQuick3DPrincipledMaterial::heightChannelChanged, 36))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(float )>(_a, &QQuick3DPrincipledMaterial::heightAmountChanged, 37))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(int )>(_a, &QQuick3DPrincipledMaterial::minHeightMapSamplesChanged, 38))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(int )>(_a, &QQuick3DPrincipledMaterial::maxHeightMapSamplesChanged, 39))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(float )>(_a, &QQuick3DPrincipledMaterial::clearcoatAmountChanged, 40))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DTexture * )>(_a, &QQuick3DPrincipledMaterial::clearcoatMapChanged, 41))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DMaterial::TextureChannelMapping )>(_a, &QQuick3DPrincipledMaterial::clearcoatChannelChanged, 42))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(float )>(_a, &QQuick3DPrincipledMaterial::clearcoatRoughnessAmountChanged, 43))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DMaterial::TextureChannelMapping )>(_a, &QQuick3DPrincipledMaterial::clearcoatRoughnessChannelChanged, 44))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DTexture * )>(_a, &QQuick3DPrincipledMaterial::clearcoatRoughnessMapChanged, 45))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DTexture * )>(_a, &QQuick3DPrincipledMaterial::clearcoatNormalMapChanged, 46))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(float )>(_a, &QQuick3DPrincipledMaterial::clearcoatNormalStrengthChanged, 47))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(float )>(_a, &QQuick3DPrincipledMaterial::transmissionFactorChanged, 48))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DTexture * )>(_a, &QQuick3DPrincipledMaterial::transmissionMapChanged, 49))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DMaterial::TextureChannelMapping )>(_a, &QQuick3DPrincipledMaterial::transmissionChannelChanged, 50))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(float )>(_a, &QQuick3DPrincipledMaterial::thicknessFactorChanged, 51))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DTexture * )>(_a, &QQuick3DPrincipledMaterial::thicknessMapChanged, 52))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QQuick3DMaterial::TextureChannelMapping )>(_a, &QQuick3DPrincipledMaterial::thicknessChannelChanged, 53))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(float )>(_a, &QQuick3DPrincipledMaterial::attenuationDistanceChanged, 54))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(QColor )>(_a, &QQuick3DPrincipledMaterial::attenuationColorChanged, 55))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(float )>(_a, &QQuick3DPrincipledMaterial::indexOfRefractionChanged, 56))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(bool )>(_a, &QQuick3DPrincipledMaterial::fresnelScaleBiasEnabledChanged, 57))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(float )>(_a, &QQuick3DPrincipledMaterial::fresnelScaleChanged, 58))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(float )>(_a, &QQuick3DPrincipledMaterial::fresnelBiasChanged, 59))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(float )>(_a, &QQuick3DPrincipledMaterial::fresnelPowerChanged, 60))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(bool )>(_a, &QQuick3DPrincipledMaterial::clearcoatFresnelScaleBiasEnabledChanged, 61))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(float )>(_a, &QQuick3DPrincipledMaterial::clearcoatFresnelScaleChanged, 62))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(float )>(_a, &QQuick3DPrincipledMaterial::clearcoatFresnelBiasChanged, 63))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(float )>(_a, &QQuick3DPrincipledMaterial::clearcoatFresnelPowerChanged, 64))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)(bool )>(_a, &QQuick3DPrincipledMaterial::vertexColorsEnabledChanged, 65))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)()>(_a, &QQuick3DPrincipledMaterial::vertexColorsMaskEnabledChanged, 66))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)()>(_a, &QQuick3DPrincipledMaterial::vertexColorRedMaskChanged, 67))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)()>(_a, &QQuick3DPrincipledMaterial::vertexColorGreenMaskChanged, 68))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)()>(_a, &QQuick3DPrincipledMaterial::vertexColorBlueMaskChanged, 69))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DPrincipledMaterial::*)()>(_a, &QQuick3DPrincipledMaterial::vertexColorAlphaMaskChanged, 70))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 52:
        case 49:
        case 46:
        case 45:
        case 41:
        case 35:
        case 28:
        case 27:
        case 25:
        case 23:
        case 18:
        case 15:
        case 10:
        case 7:
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DTexture* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum Lighting*>(_v) = _t->lighting(); break;
        case 1: *reinterpret_cast<enum BlendMode*>(_v) = _t->blendMode(); break;
        case 2: *reinterpret_cast<QColor*>(_v) = _t->baseColor(); break;
        case 3: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->baseColorMap(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->baseColorSingleChannelEnabled(); break;
        case 5: *reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v) = _t->baseColorChannel(); break;
        case 6: *reinterpret_cast<float*>(_v) = _t->metalness(); break;
        case 7: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->metalnessMap(); break;
        case 8: *reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v) = _t->metalnessChannel(); break;
        case 9: *reinterpret_cast<float*>(_v) = _t->specularAmount(); break;
        case 10: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->specularMap(); break;
        case 11: *reinterpret_cast<float*>(_v) = _t->specularTint(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->specularSingleChannelEnabled(); break;
        case 13: *reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v) = _t->specularChannel(); break;
        case 14: *reinterpret_cast<float*>(_v) = _t->roughness(); break;
        case 15: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->roughnessMap(); break;
        case 16: *reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v) = _t->roughnessChannel(); break;
        case 17: *reinterpret_cast<QVector3D*>(_v) = _t->emissiveFactor(); break;
        case 18: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->emissiveMap(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->emissiveSingleChannelEnabled(); break;
        case 20: *reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v) = _t->emissiveChannel(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->invertOpacityMapValue(); break;
        case 22: *reinterpret_cast<float*>(_v) = _t->opacity(); break;
        case 23: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->opacityMap(); break;
        case 24: *reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v) = _t->opacityChannel(); break;
        case 25: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->normalMap(); break;
        case 26: *reinterpret_cast<float*>(_v) = _t->normalStrength(); break;
        case 27: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->specularReflectionMap(); break;
        case 28: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->occlusionMap(); break;
        case 29: *reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v) = _t->occlusionChannel(); break;
        case 30: *reinterpret_cast<float*>(_v) = _t->occlusionAmount(); break;
        case 31: *reinterpret_cast<enum AlphaMode*>(_v) = _t->alphaMode(); break;
        case 32: *reinterpret_cast<float*>(_v) = _t->alphaCutoff(); break;
        case 33: *reinterpret_cast<float*>(_v) = _t->pointSize(); break;
        case 34: *reinterpret_cast<float*>(_v) = _t->lineWidth(); break;
        case 35: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->heightMap(); break;
        case 36: *reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v) = _t->heightChannel(); break;
        case 37: *reinterpret_cast<float*>(_v) = _t->heightAmount(); break;
        case 38: *reinterpret_cast<int*>(_v) = _t->minHeightMapSamples(); break;
        case 39: *reinterpret_cast<int*>(_v) = _t->maxHeightMapSamples(); break;
        case 40: *reinterpret_cast<float*>(_v) = _t->clearcoatAmount(); break;
        case 41: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->clearcoatMap(); break;
        case 42: *reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v) = _t->clearcoatChannel(); break;
        case 43: *reinterpret_cast<float*>(_v) = _t->clearcoatRoughnessAmount(); break;
        case 44: *reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v) = _t->clearcoatRoughnessChannel(); break;
        case 45: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->clearcoatRoughnessMap(); break;
        case 46: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->clearcoatNormalMap(); break;
        case 47: *reinterpret_cast<float*>(_v) = _t->clearcoatNormalStrength(); break;
        case 48: *reinterpret_cast<float*>(_v) = _t->transmissionFactor(); break;
        case 49: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->transmissionMap(); break;
        case 50: *reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v) = _t->transmissionChannel(); break;
        case 51: *reinterpret_cast<float*>(_v) = _t->thicknessFactor(); break;
        case 52: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->thicknessMap(); break;
        case 53: *reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v) = _t->thicknessChannel(); break;
        case 54: *reinterpret_cast<float*>(_v) = _t->attenuationDistance(); break;
        case 55: *reinterpret_cast<QColor*>(_v) = _t->attenuationColor(); break;
        case 56: *reinterpret_cast<float*>(_v) = _t->indexOfRefraction(); break;
        case 57: *reinterpret_cast<bool*>(_v) = _t->vertexColorsEnabled(); break;
        case 58: *reinterpret_cast<bool*>(_v) = _t->fresnelScaleBiasEnabled(); break;
        case 59: *reinterpret_cast<float*>(_v) = _t->fresnelScale(); break;
        case 60: *reinterpret_cast<float*>(_v) = _t->fresnelBias(); break;
        case 61: *reinterpret_cast<float*>(_v) = _t->fresnelPower(); break;
        case 62: *reinterpret_cast<bool*>(_v) = _t->clearcoatFresnelScaleBiasEnabled(); break;
        case 63: *reinterpret_cast<float*>(_v) = _t->clearcoatFresnelScale(); break;
        case 64: *reinterpret_cast<float*>(_v) = _t->clearcoatFresnelBias(); break;
        case 65: *reinterpret_cast<float*>(_v) = _t->clearcoatFresnelPower(); break;
        case 66: *reinterpret_cast<bool*>(_v) = _t->vertexColorsMaskEnabled(); break;
        case 67: QtMocHelpers::assignFlags<VertexColorMaskFlags>(_v, _t->vertexColorRedMask()); break;
        case 68: QtMocHelpers::assignFlags<VertexColorMaskFlags>(_v, _t->vertexColorGreenMask()); break;
        case 69: QtMocHelpers::assignFlags<VertexColorMaskFlags>(_v, _t->vertexColorBlueMask()); break;
        case 70: QtMocHelpers::assignFlags<VertexColorMaskFlags>(_v, _t->vertexColorAlphaMask()); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLighting(*reinterpret_cast<enum Lighting*>(_v)); break;
        case 1: _t->setBlendMode(*reinterpret_cast<enum BlendMode*>(_v)); break;
        case 2: _t->setBaseColor(*reinterpret_cast<QColor*>(_v)); break;
        case 3: _t->setBaseColorMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 4: _t->setBaseColorSingleChannelEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setBaseColorChannel(*reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v)); break;
        case 6: _t->setMetalness(*reinterpret_cast<float*>(_v)); break;
        case 7: _t->setMetalnessMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 8: _t->setMetalnessChannel(*reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v)); break;
        case 9: _t->setSpecularAmount(*reinterpret_cast<float*>(_v)); break;
        case 10: _t->setSpecularMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 11: _t->setSpecularTint(*reinterpret_cast<float*>(_v)); break;
        case 12: _t->setSpecularSingleChannelEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setSpecularChannel(*reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v)); break;
        case 14: _t->setRoughness(*reinterpret_cast<float*>(_v)); break;
        case 15: _t->setRoughnessMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 16: _t->setRoughnessChannel(*reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v)); break;
        case 17: _t->setEmissiveFactor(*reinterpret_cast<QVector3D*>(_v)); break;
        case 18: _t->setEmissiveMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 19: _t->setEmissiveSingleChannelEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 20: _t->setEmissiveChannel(*reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v)); break;
        case 21: _t->setInvertOpacityMapValue(*reinterpret_cast<bool*>(_v)); break;
        case 22: _t->setOpacity(*reinterpret_cast<float*>(_v)); break;
        case 23: _t->setOpacityMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 24: _t->setOpacityChannel(*reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v)); break;
        case 25: _t->setNormalMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 26: _t->setNormalStrength(*reinterpret_cast<float*>(_v)); break;
        case 27: _t->setSpecularReflectionMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 28: _t->setOcclusionMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 29: _t->setOcclusionChannel(*reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v)); break;
        case 30: _t->setOcclusionAmount(*reinterpret_cast<float*>(_v)); break;
        case 31: _t->setAlphaMode(*reinterpret_cast<enum AlphaMode*>(_v)); break;
        case 32: _t->setAlphaCutoff(*reinterpret_cast<float*>(_v)); break;
        case 33: _t->setPointSize(*reinterpret_cast<float*>(_v)); break;
        case 34: _t->setLineWidth(*reinterpret_cast<float*>(_v)); break;
        case 35: _t->setHeightMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 36: _t->setHeightChannel(*reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v)); break;
        case 37: _t->setHeightAmount(*reinterpret_cast<float*>(_v)); break;
        case 38: _t->setMinHeightMapSamples(*reinterpret_cast<int*>(_v)); break;
        case 39: _t->setMaxHeightMapSamples(*reinterpret_cast<int*>(_v)); break;
        case 40: _t->setClearcoatAmount(*reinterpret_cast<float*>(_v)); break;
        case 41: _t->setClearcoatMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 42: _t->setClearcoatChannel(*reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v)); break;
        case 43: _t->setClearcoatRoughnessAmount(*reinterpret_cast<float*>(_v)); break;
        case 44: _t->setClearcoatRoughnessChannel(*reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v)); break;
        case 45: _t->setClearcoatRoughnessMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 46: _t->setClearcoatNormalMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 47: _t->setClearcoatNormalStrength(*reinterpret_cast<float*>(_v)); break;
        case 48: _t->setTransmissionFactor(*reinterpret_cast<float*>(_v)); break;
        case 49: _t->setTransmissionMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 50: _t->setTransmissionChannel(*reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v)); break;
        case 51: _t->setThicknessFactor(*reinterpret_cast<float*>(_v)); break;
        case 52: _t->setThicknessMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 53: _t->setThicknessChannel(*reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v)); break;
        case 54: _t->setAttenuationDistance(*reinterpret_cast<float*>(_v)); break;
        case 55: _t->setAttenuationColor(*reinterpret_cast<QColor*>(_v)); break;
        case 56: _t->setIndexOfRefraction(*reinterpret_cast<float*>(_v)); break;
        case 57: _t->setVertexColorsEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 58: _t->setFresnelScaleBiasEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 59: _t->setFresnelScale(*reinterpret_cast<float*>(_v)); break;
        case 60: _t->setFresnelBias(*reinterpret_cast<float*>(_v)); break;
        case 61: _t->setFresnelPower(*reinterpret_cast<float*>(_v)); break;
        case 62: _t->setClearcoatFresnelScaleBiasEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 63: _t->setClearcoatFresnelScale(*reinterpret_cast<float*>(_v)); break;
        case 64: _t->setClearcoatFresnelBias(*reinterpret_cast<float*>(_v)); break;
        case 65: _t->setClearcoatFresnelPower(*reinterpret_cast<float*>(_v)); break;
        case 66: _t->setVertexColorsMaskEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 67: _t->setVertexColorRedMask(*reinterpret_cast<VertexColorMaskFlags*>(_v)); break;
        case 68: _t->setVertexColorGreenMask(*reinterpret_cast<VertexColorMaskFlags*>(_v)); break;
        case 69: _t->setVertexColorBlueMask(*reinterpret_cast<VertexColorMaskFlags*>(_v)); break;
        case 70: _t->setVertexColorAlphaMask(*reinterpret_cast<VertexColorMaskFlags*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DPrincipledMaterial::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DPrincipledMaterial::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26QQuick3DPrincipledMaterialE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DMaterial::qt_metacast(_clname);
}

int QQuick3DPrincipledMaterial::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DMaterial::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 142)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 142;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 142)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 142;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 71;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DPrincipledMaterial::lightingChanged(QQuick3DPrincipledMaterial::Lighting _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void QQuick3DPrincipledMaterial::blendModeChanged(QQuick3DPrincipledMaterial::BlendMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void QQuick3DPrincipledMaterial::baseColorChanged(QColor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void QQuick3DPrincipledMaterial::baseColorMapChanged(QQuick3DTexture * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void QQuick3DPrincipledMaterial::baseColorSingleChannelEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void QQuick3DPrincipledMaterial::baseColorChannelChanged(QQuick3DMaterial::TextureChannelMapping _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void QQuick3DPrincipledMaterial::specularSingleChannelEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void QQuick3DPrincipledMaterial::specularChannelChanged(QQuick3DMaterial::TextureChannelMapping _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void QQuick3DPrincipledMaterial::emissiveSingleChannelEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void QQuick3DPrincipledMaterial::emissiveChannelChanged(QQuick3DMaterial::TextureChannelMapping _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void QQuick3DPrincipledMaterial::emissiveMapChanged(QQuick3DTexture * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void QQuick3DPrincipledMaterial::emissiveFactorChanged(QVector3D _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void QQuick3DPrincipledMaterial::specularReflectionMapChanged(QQuick3DTexture * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void QQuick3DPrincipledMaterial::specularMapChanged(QQuick3DTexture * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void QQuick3DPrincipledMaterial::specularTintChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void QQuick3DPrincipledMaterial::specularAmountChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void QQuick3DPrincipledMaterial::roughnessChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void QQuick3DPrincipledMaterial::roughnessMapChanged(QQuick3DTexture * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void QQuick3DPrincipledMaterial::invertOpacityMapValueChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void QQuick3DPrincipledMaterial::opacityChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void QQuick3DPrincipledMaterial::opacityMapChanged(QQuick3DTexture * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void QQuick3DPrincipledMaterial::normalMapChanged(QQuick3DTexture * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void QQuick3DPrincipledMaterial::metalnessChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void QQuick3DPrincipledMaterial::metalnessMapChanged(QQuick3DTexture * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void QQuick3DPrincipledMaterial::normalStrengthChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void QQuick3DPrincipledMaterial::occlusionMapChanged(QQuick3DTexture * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1);
}

// SIGNAL 26
void QQuick3DPrincipledMaterial::occlusionAmountChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1);
}

// SIGNAL 27
void QQuick3DPrincipledMaterial::alphaModeChanged(QQuick3DPrincipledMaterial::AlphaMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 27, nullptr, _t1);
}

// SIGNAL 28
void QQuick3DPrincipledMaterial::alphaCutoffChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 28, nullptr, _t1);
}

// SIGNAL 29
void QQuick3DPrincipledMaterial::metalnessChannelChanged(QQuick3DMaterial::TextureChannelMapping _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 29, nullptr, _t1);
}

// SIGNAL 30
void QQuick3DPrincipledMaterial::roughnessChannelChanged(QQuick3DMaterial::TextureChannelMapping _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 30, nullptr, _t1);
}

// SIGNAL 31
void QQuick3DPrincipledMaterial::opacityChannelChanged(QQuick3DMaterial::TextureChannelMapping _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 31, nullptr, _t1);
}

// SIGNAL 32
void QQuick3DPrincipledMaterial::occlusionChannelChanged(QQuick3DMaterial::TextureChannelMapping _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 32, nullptr, _t1);
}

// SIGNAL 33
void QQuick3DPrincipledMaterial::pointSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 33, nullptr);
}

// SIGNAL 34
void QQuick3DPrincipledMaterial::lineWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 34, nullptr);
}

// SIGNAL 35
void QQuick3DPrincipledMaterial::heightMapChanged(QQuick3DTexture * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 35, nullptr, _t1);
}

// SIGNAL 36
void QQuick3DPrincipledMaterial::heightChannelChanged(QQuick3DMaterial::TextureChannelMapping _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 36, nullptr, _t1);
}

// SIGNAL 37
void QQuick3DPrincipledMaterial::heightAmountChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 37, nullptr, _t1);
}

// SIGNAL 38
void QQuick3DPrincipledMaterial::minHeightMapSamplesChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 38, nullptr, _t1);
}

// SIGNAL 39
void QQuick3DPrincipledMaterial::maxHeightMapSamplesChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 39, nullptr, _t1);
}

// SIGNAL 40
void QQuick3DPrincipledMaterial::clearcoatAmountChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 40, nullptr, _t1);
}

// SIGNAL 41
void QQuick3DPrincipledMaterial::clearcoatMapChanged(QQuick3DTexture * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 41, nullptr, _t1);
}

// SIGNAL 42
void QQuick3DPrincipledMaterial::clearcoatChannelChanged(QQuick3DMaterial::TextureChannelMapping _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 42, nullptr, _t1);
}

// SIGNAL 43
void QQuick3DPrincipledMaterial::clearcoatRoughnessAmountChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 43, nullptr, _t1);
}

// SIGNAL 44
void QQuick3DPrincipledMaterial::clearcoatRoughnessChannelChanged(QQuick3DMaterial::TextureChannelMapping _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 44, nullptr, _t1);
}

// SIGNAL 45
void QQuick3DPrincipledMaterial::clearcoatRoughnessMapChanged(QQuick3DTexture * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 45, nullptr, _t1);
}

// SIGNAL 46
void QQuick3DPrincipledMaterial::clearcoatNormalMapChanged(QQuick3DTexture * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 46, nullptr, _t1);
}

// SIGNAL 47
void QQuick3DPrincipledMaterial::clearcoatNormalStrengthChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 47, nullptr, _t1);
}

// SIGNAL 48
void QQuick3DPrincipledMaterial::transmissionFactorChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 48, nullptr, _t1);
}

// SIGNAL 49
void QQuick3DPrincipledMaterial::transmissionMapChanged(QQuick3DTexture * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 49, nullptr, _t1);
}

// SIGNAL 50
void QQuick3DPrincipledMaterial::transmissionChannelChanged(QQuick3DMaterial::TextureChannelMapping _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 50, nullptr, _t1);
}

// SIGNAL 51
void QQuick3DPrincipledMaterial::thicknessFactorChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 51, nullptr, _t1);
}

// SIGNAL 52
void QQuick3DPrincipledMaterial::thicknessMapChanged(QQuick3DTexture * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 52, nullptr, _t1);
}

// SIGNAL 53
void QQuick3DPrincipledMaterial::thicknessChannelChanged(QQuick3DMaterial::TextureChannelMapping _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 53, nullptr, _t1);
}

// SIGNAL 54
void QQuick3DPrincipledMaterial::attenuationDistanceChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 54, nullptr, _t1);
}

// SIGNAL 55
void QQuick3DPrincipledMaterial::attenuationColorChanged(QColor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 55, nullptr, _t1);
}

// SIGNAL 56
void QQuick3DPrincipledMaterial::indexOfRefractionChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 56, nullptr, _t1);
}

// SIGNAL 57
void QQuick3DPrincipledMaterial::fresnelScaleBiasEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 57, nullptr, _t1);
}

// SIGNAL 58
void QQuick3DPrincipledMaterial::fresnelScaleChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 58, nullptr, _t1);
}

// SIGNAL 59
void QQuick3DPrincipledMaterial::fresnelBiasChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 59, nullptr, _t1);
}

// SIGNAL 60
void QQuick3DPrincipledMaterial::fresnelPowerChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 60, nullptr, _t1);
}

// SIGNAL 61
void QQuick3DPrincipledMaterial::clearcoatFresnelScaleBiasEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 61, nullptr, _t1);
}

// SIGNAL 62
void QQuick3DPrincipledMaterial::clearcoatFresnelScaleChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 62, nullptr, _t1);
}

// SIGNAL 63
void QQuick3DPrincipledMaterial::clearcoatFresnelBiasChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 63, nullptr, _t1);
}

// SIGNAL 64
void QQuick3DPrincipledMaterial::clearcoatFresnelPowerChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 64, nullptr, _t1);
}

// SIGNAL 65
void QQuick3DPrincipledMaterial::vertexColorsEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 65, nullptr, _t1);
}

// SIGNAL 66
void QQuick3DPrincipledMaterial::vertexColorsMaskEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 66, nullptr);
}

// SIGNAL 67
void QQuick3DPrincipledMaterial::vertexColorRedMaskChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 67, nullptr);
}

// SIGNAL 68
void QQuick3DPrincipledMaterial::vertexColorGreenMaskChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 68, nullptr);
}

// SIGNAL 69
void QQuick3DPrincipledMaterial::vertexColorBlueMaskChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 69, nullptr);
}

// SIGNAL 70
void QQuick3DPrincipledMaterial::vertexColorAlphaMaskChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 70, nullptr);
}
QT_WARNING_POP
